==> vue-modal-3.23.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix, setupComponent, createComponent } from "@opentinyvue/vue-common";
import { MsgQueue } from "@opentinyvue/vue-renderless/modal";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
import Popconfirm from "@opentinyvue/vue-popconfirm";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var $constants = {
  MODAL_STATUS: {
    INFO: "info",
    SUCCESS: "success",
    WARNING: "warning",
    ERROR: "error",
    LOADING: "loading"
  },
  NODAL_TYPE: {
    ALERT: "alert",
    CONFIRM: "confirm",
    MESSAGE: "message"
  },
  STATUS_MAPPING_CLASSS: {
    INFO: "tiny-modal-svg__info",
    SUCCESS: "tiny-modal-svg__success",
    WARNING: "tiny-modal-svg__warning",
    ERROR: "tiny-modal-svg__error",
    LOADING: "tiny-modal-svg__refresh roll"
  },
  PC_SCROLL_LOCK_CLASS: "dialog-box__scroll-lock",
  MOBILE_FIRST_SCROLL_LOCK_CLASS: "tiny-modal-lockscroll",
  Mode: "pc",
  SCROLL_LOCK_CLASS: function SCROLL_LOCK_CLASS(mode) {
    return mode === this.Mode ? this.PC_SCROLL_LOCK_CLASS : this.MOBILE_FIRST_SCROLL_LOCK_CLASS;
  }
};
var modalProps = _extends({}, $props, {
  _constants: {
    type: Object,
    default: function _default() {
      return $constants;
    }
  },
  animat: {
    type: Boolean,
    default: function _default2() {
      return true;
    }
  },
  beforeClose: Function,
  duration: {
    type: [Number, String],
    default: function _default3() {
      return 3e3;
    }
  },
  messageClosable: Boolean,
  escClosable: Boolean,
  events: Object,
  fullscreen: Boolean,
  height: [Number, String],
  id: String,
  isFormReset: {
    type: Boolean,
    default: true
  },
  lockScroll: Boolean,
  lockView: {
    type: Boolean,
    default: function _default4() {
      return true;
    }
  },
  marginSize: {
    type: [Number, String],
    default: 10
  },
  mask: {
    type: Boolean,
    default: function _default5() {
      return true;
    }
  },
  maskClosable: Boolean,
  message: [String, Function, Object],
  minHeight: {
    type: [Number, String],
    default: function _default6() {
      return 200;
    }
  },
  minWidth: {
    type: [Number, String],
    default: function _default7() {
      return 340;
    }
  },
  modelValue: Boolean,
  resize: Boolean,
  showFooter: Boolean,
  showHeader: {
    type: Boolean,
    default: true
  },
  status: {
    type: [String, Object],
    default: ""
  },
  title: String,
  top: {
    type: [Number, String],
    default: 80
  },
  type: {
    type: String,
    default: "alert"
  },
  vSize: String,
  width: [Number, String],
  zIndex: [Number, String],
  description: String,
  // mf 属性
  options: Array,
  // mf 属性
  showClose: {
    type: Boolean,
    default: true
  },
  // mf 属性
  confirmContent: String,
  cancelContent: String,
  position: {
    type: String,
    // mf 属性
    default: "",
    validator: function validator(val) {
      return ["", "bottom-right"].includes(val);
    }
  },
  customClass: String,
  // mf 属性
  confirmBtnProps: {
    type: Object,
    default: function _default8() {
      return {};
    }
  },
  cancelBtnProps: {
    type: Object,
    default: function _default9() {
      return {};
    }
  },
  footerDragable: Boolean,
  tiny_theme: String,
  slots: Object
});
var TINYModal = defineComponent({
  name: $prefix + "Modal",
  componentName: "Modal",
  props: modalProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "3.23.0";
var TINYModalComponent = TINYModal;
TINYModalComponent.version = version;
TINYModalComponent.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
function Modal(options) {
  var modalPromise = new Promise(function(resolve) {
    if (options && options.id && MsgQueue.some(function(comp) {
      return comp.id === options.id;
    })) {
      resolve("exist");
    } else {
      var events = options.events || {};
      var $modal;
      options.events = Object.assign({}, events, {
        hide: function hide(params) {
          events.hide && events.hide.call(this, params);
          if ($modal && "beforeUnmouted" in $modal) {
            $modal.beforeUnmouted();
          }
          resolve(params.type);
        },
        confirm: function confirm2(params) {
          events.confirm && events.confirm.call(this, params);
        },
        show: function show(params) {
          events.show && events.show.call(this, params);
        }
      });
      $modal = createComponent({
        el: document.createElement("div"),
        propsData: Object.assign({
          "tiny_mode": TINYModalComponent.tiny_mode,
          "tiny_theme": TINYModalComponent.tiny_theme
        }, options),
        component: options.componentType === "popconfirm" ? Popconfirm : TINYModalComponent
      });
      var open = $modal[options.componentType === "popconfirm" ? "show" : "open"];
      if (open) {
        open();
      }
      setTimeout(function() {
        modalPromise.vm = $modal;
      }, 0);
    }
  });
  return modalPromise;
}
var modal = Modal;
var types = ["alert", "confirm", "message", "popconfirm"];
var defOpts = {
  alert: {
    showFooter: true,
    type: "alert"
  },
  confirm: {
    showFooter: true,
    status: "question",
    type: "confirm"
  },
  message: {
    mask: false,
    lockView: false,
    showHeader: false,
    showClose: false,
    type: "message"
  },
  popconfirm: {}
};
types.forEach(function(type) {
  TINYModalComponent[type] = Modal[type] = function(message2, title, options) {
    var opts = {};
    if (typeof message2 === "object" && message2 !== null) {
      opts = message2;
    } else if (title) {
      opts = {
        title
      };
    }
    if (message2 === void 0 || message2 === null) {
      message2 = "";
    }
    return modal(_extends({
      message: message2.toString()
    }, defOpts[type], opts, options, {
      componentType: type
    }));
  };
});
var alert = Modal.alert;
var message = Modal.message;
var confirm = Modal.confirm;
var popconfirm = Modal.popconfirm;
TINYModalComponent.installed = false;
setupComponent.TINYModal = {
  install: function install(Vue) {
    var _process$env2;
    if (TINYModalComponent.installed) return;
    var isVue2 = !!Vue.component;
    var tinyMode = isVue2 ? Vue.prototype.tiny_mode : Vue.config.globalProperties.tiny_mode;
    var tinyTheme = isVue2 ? Vue.prototype.tiny_theme : Vue.config.globalProperties.tiny_theme;
    var specifyPc = typeof process === "object" ? (_process$env2 = process.env) == null ? void 0 : _process$env2.TINY_MODE : null;
    TINYModalComponent.tiny_mode = specifyPc || tinyMode && tinyMode.value;
    TINYModalComponent.tiny_theme = tinyTheme && tinyTheme.value;
    TINYModalComponent.installed = true;
  },
  init: function init(root) {
    var prefix = root.$TinyModalApiPrefix || root.$apiPrefix || "$";
    root[prefix + "alert"] = Modal.alert;
    root[prefix + "message"] = Modal.message;
    root[prefix + "confirm"] = Modal.confirm;
    root[prefix + "popconfirm"] = Modal.popconfirm;
  }
};
TINYModalComponent.install = function(Vue) {
  Vue.component(TINYModalComponent.name, TINYModalComponent);
};
export {
  Modal,
  alert,
  confirm,
  TINYModalComponent as default,
  message,
  popconfirm
};

==> vue-modal-3.24.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix, setupComponent, createComponent } from "@opentiny/vue-common";
import { MsgQueue } from "@opentiny/vue-renderless/modal";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
import Popconfirm from "@opentiny/vue-popconfirm";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var $constants = {
  MODAL_STATUS: {
    INFO: "info",
    SUCCESS: "success",
    WARNING: "warning",
    ERROR: "error",
    LOADING: "loading"
  },
  NODAL_TYPE: {
    ALERT: "alert",
    CONFIRM: "confirm",
    MESSAGE: "message"
  },
  STATUS_MAPPING_CLASSS: {
    INFO: "tiny-modal-svg__info",
    SUCCESS: "tiny-modal-svg__success",
    WARNING: "tiny-modal-svg__warning",
    ERROR: "tiny-modal-svg__error",
    LOADING: "tiny-modal-svg__refresh roll"
  },
  PC_SCROLL_LOCK_CLASS: "dialog-box__scroll-lock",
  MOBILE_FIRST_SCROLL_LOCK_CLASS: "tiny-modal-lockscroll",
  Mode: "pc",
  SCROLL_LOCK_CLASS: function SCROLL_LOCK_CLASS(mode) {
    return mode === this.Mode ? this.PC_SCROLL_LOCK_CLASS : this.MOBILE_FIRST_SCROLL_LOCK_CLASS;
  }
};
var modalProps = _extends({}, $props, {
  _constants: {
    type: Object,
    default: function _default() {
      return $constants;
    }
  },
  animat: {
    type: Boolean,
    default: function _default2() {
      return true;
    }
  },
  beforeClose: Function,
  duration: {
    type: [Number, String],
    default: function _default3() {
      return 3e3;
    }
  },
  messageClosable: Boolean,
  escClosable: Boolean,
  events: Object,
  fullscreen: Boolean,
  height: [Number, String],
  id: String,
  isFormReset: {
    type: Boolean,
    default: true
  },
  lockScroll: Boolean,
  lockView: {
    type: Boolean,
    default: function _default4() {
      return true;
    }
  },
  marginSize: {
    type: [Number, String],
    default: 10
  },
  mask: {
    type: Boolean,
    default: function _default5() {
      return true;
    }
  },
  maskClosable: Boolean,
  message: [String, Function, Object],
  minHeight: {
    type: [Number, String],
    default: function _default6() {
      return 200;
    }
  },
  minWidth: {
    type: [Number, String],
    default: function _default7() {
      return 340;
    }
  },
  modelValue: Boolean,
  resize: Boolean,
  showFooter: Boolean,
  showHeader: {
    type: Boolean,
    default: true
  },
  status: {
    type: [String, Object],
    default: ""
  },
  title: String,
  top: {
    type: [Number, String],
    default: 80
  },
  type: {
    type: String,
    default: "alert"
  },
  vSize: String,
  width: [Number, String],
  zIndex: [Number, String],
  description: String,
  // mf 属性
  options: Array,
  // mf 属性
  showClose: {
    type: Boolean,
    default: true
  },
  // mf 属性
  confirmContent: String,
  cancelContent: String,
  position: {
    type: String,
    // mf 属性
    default: "",
    validator: function validator(val) {
      return ["", "bottom-right"].includes(val);
    }
  },
  customClass: String,
  // mf 属性
  confirmBtnProps: {
    type: Object,
    default: function _default8() {
      return {};
    }
  },
  cancelBtnProps: {
    type: Object,
    default: function _default9() {
      return {};
    }
  },
  footerDragable: Boolean,
  tiny_theme: String,
  slots: Object
});
var TINYModal = defineComponent({
  name: $prefix + "Modal",
  componentName: "Modal",
  props: modalProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "3.undefined";
var TINYModalComponent = TINYModal;
TINYModalComponent.version = version;
TINYModalComponent.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
function Modal(options) {
  var modalPromise = new Promise(function(resolve) {
    if (options && options.id && MsgQueue.some(function(comp) {
      return comp.id === options.id;
    })) {
      resolve("exist");
    } else {
      var events = options.events || {};
      var $modal;
      options.events = Object.assign({}, events, {
        hide: function hide(params) {
          events.hide && events.hide.call(this, params);
          if ($modal && "beforeUnmouted" in $modal) {
            $modal.beforeUnmouted();
          }
          resolve(params.type);
        },
        confirm: function confirm2(params) {
          events.confirm && events.confirm.call(this, params);
        },
        show: function show(params) {
          events.show && events.show.call(this, params);
        }
      });
      $modal = createComponent({
        el: document.createElement("div"),
        propsData: Object.assign({
          "tiny_mode": TINYModalComponent.tiny_mode,
          "tiny_theme": TINYModalComponent.tiny_theme
        }, options),
        component: options.componentType === "popconfirm" ? Popconfirm : TINYModalComponent
      });
      var open = $modal[options.componentType === "popconfirm" ? "show" : "open"];
      if (open) {
        open();
      }
      setTimeout(function() {
        modalPromise.vm = $modal;
      }, 0);
    }
  });
  return modalPromise;
}
var modal = Modal;
var types = ["alert", "confirm", "message", "popconfirm"];
var defOpts = {
  alert: {
    showFooter: true,
    type: "alert"
  },
  confirm: {
    showFooter: true,
    status: "question",
    type: "confirm"
  },
  message: {
    mask: false,
    lockView: false,
    showHeader: false,
    showClose: false,
    type: "message"
  },
  popconfirm: {}
};
types.forEach(function(type) {
  TINYModalComponent[type] = Modal[type] = function(message2, title, options) {
    var opts = {};
    if (typeof message2 === "object" && message2 !== null) {
      opts = message2;
    } else if (title) {
      opts = {
        title
      };
    }
    if (message2 === void 0 || message2 === null) {
      message2 = "";
    }
    return modal(_extends({
      message: message2.toString()
    }, defOpts[type], opts, options, {
      componentType: type
    }));
  };
});
var alert = Modal.alert;
var message = Modal.message;
var confirm = Modal.confirm;
var popconfirm = Modal.popconfirm;
TINYModalComponent.installed = false;
setupComponent.TINYModal = {
  install: function install(Vue) {
    var _process$env2;
    if (TINYModalComponent.installed) return;
    var isVue2 = !!Vue.component;
    var tinyMode = isVue2 ? Vue.prototype.tiny_mode : Vue.config.globalProperties.tiny_mode;
    var tinyTheme = isVue2 ? Vue.prototype.tiny_theme : Vue.config.globalProperties.tiny_theme;
    var specifyPc = typeof process === "object" ? (_process$env2 = process.env) == null ? void 0 : _process$env2.TINY_MODE : null;
    TINYModalComponent.tiny_mode = specifyPc || tinyMode && tinyMode.value;
    TINYModalComponent.tiny_theme = tinyTheme && tinyTheme.value;
    TINYModalComponent.installed = true;
  },
  init: function init(root) {
    var prefix = root.$TinyModalApiPrefix || root.$apiPrefix || "$";
    root[prefix + "alert"] = Modal.alert;
    root[prefix + "message"] = Modal.message;
    root[prefix + "confirm"] = Modal.confirm;
    root[prefix + "popconfirm"] = Modal.popconfirm;
  }
};
TINYModalComponent.install = function(Vue) {
  Vue.component(TINYModalComponent.name, TINYModalComponent);
};
export {
  Modal,
  alert,
  confirm,
  TINYModalComponent as default,
  message,
  popconfirm
};
